==> haskell-unix-compat-0.7.4-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.4
visibility:           public
id:                   unix-compat-0.7.4-FtHhyYNKXNEEfGBWiva7Zs
key:                  unix-compat-0.7.4-FtHhyYNKXNEEfGBWiva7Zs
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  a72c6a3b6dc651ef0eb7480f1805991c
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.4-FtHhyYNKXNEEfGBWiva7Zs
include-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4/include
includes:             HsUnixCompat.h
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.7.4-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.4
visibility:           public
id:                   unix-compat-0.7.4-BZWTyxtN7nl3Z0fwlVJ8w5
key:                  unix-compat-0.7.4-BZWTyxtN7nl3Z0fwlVJ8w5
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  956516bbf8220fdc273ace8f61ffaf08
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.4-BZWTyxtN7nl3Z0fwlVJ8w5
include-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-compat-0.7.4/include
includes:             HsUnixCompat.h
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
